pub struct Client { /* private fields */ }Implementations
Sourceimpl Client
impl Client
Sourcepub fn builder(credential: Arc<dyn TokenCredential>) -> ClientBuilder
pub fn builder(credential: Arc<dyn TokenCredential>) -> ClientBuilder
Create a new ClientBuilder.
Sourcepub fn new(
endpoint: impl Into<Url>,
credential: Arc<dyn TokenCredential>,
scopes: Vec<String>,
options: ClientOptions,
) -> Self
pub fn new( endpoint: impl Into<Url>, credential: Arc<dyn TokenCredential>, scopes: Vec<String>, options: ClientOptions, ) -> Self
Create a new Client.
pub fn operations_client(&self) -> Client
pub fn workflow_client(&self) -> Client
Sourceimpl Client
impl Client
Sourcepub fn git_hub_o_auth(
&self,
subscription_id: impl Into<String>,
location: impl Into<String>,
) -> RequestBuilder
pub fn git_hub_o_auth( &self, subscription_id: impl Into<String>, location: impl Into<String>, ) -> RequestBuilder
Gets GitHubOAuth info used to authenticate users with the Developer Hub GitHub App.
Arguments:
subscription_id: The ID of the target subscription.location: The name of Azure region.
Sourcepub fn git_hub_o_auth_callback(
&self,
subscription_id: impl Into<String>,
location: impl Into<String>,
code: impl Into<String>,
state: impl Into<String>,
) -> RequestBuilder
pub fn git_hub_o_auth_callback( &self, subscription_id: impl Into<String>, location: impl Into<String>, code: impl Into<String>, state: impl Into<String>, ) -> RequestBuilder
Callback URL to hit once authenticated with GitHub App to have the service store the OAuth token.
Arguments:
subscription_id: The ID of the target subscription.location: The name of Azure region.code: The code response from authenticating the GitHub App.state: The state response from authenticating the GitHub App.
Sourcepub fn list_git_hub_o_auth(
&self,
subscription_id: impl Into<String>,
location: impl Into<String>,
) -> RequestBuilder
pub fn list_git_hub_o_auth( &self, subscription_id: impl Into<String>, location: impl Into<String>, ) -> RequestBuilder
Callback URL to hit once authenticated with GitHub App to have the service store the OAuth token.
Arguments:
subscription_id: The ID of the target subscription.location: The name of Azure region.
Sourcepub fn generate_preview_artifacts(
&self,
subscription_id: impl Into<String>,
location: impl Into<String>,
parameters: impl Into<ArtifactGenerationProperties>,
) -> RequestBuilder
pub fn generate_preview_artifacts( &self, subscription_id: impl Into<String>, location: impl Into<String>, parameters: impl Into<ArtifactGenerationProperties>, ) -> RequestBuilder
Generate preview dockerfile and manifests.
Arguments:
subscription_id: The ID of the target subscription.location: The name of Azure region.